@@ -19,6 +19,7 @@ import serial
 import time
 
 from ..utils import debug_hex
+from ..utils.base_serial import BaseSerialPort
 
 
 class MIS1GCUDisplay:
@@ -44,7 +45,7 @@ class MIS1GCUDisplay:
     def __init__(self, port, address = 1, baudrate = 9600, exclusive = True, debug = False):
         self.address = address
         self.debug = debug
-        if isinstance(port, serial.Serial):
+        if isinstance(port, serial.Serial) or isinstance(port, BaseSerialPort):
             self.port = port
         else:
             self.port = serial.Serial(port, baudrate=baudrate, bytesize=8, parity="E", stopbits=1, exclusive=exclusive)
