@@ -18,6 +18,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import serial
 import time
 
+from ..utils.base_serial import BaseSerialPort
+
 
 class Krone9000FBM:
     """
@@ -66,7 +68,10 @@ class Krone9000FBM:
 
     def __init__(self, port, debug = False, exclusive = False):
         self.debug = debug
-        self.port = serial.Serial(port, baudrate=4800, parity=serial.PARITY_EVEN, timeout=2.0, exclusive=exclusive)
+        if isinstance(port, serial.Serial) or isinstance(port, BaseSerialPort):
+            self.port = port
+        else:
+            self.port = serial.Serial(port, baudrate=4800, parity=serial.PARITY_EVEN, timeout=2.0, exclusive=exclusive)
     
     def send_command(self, command, address = None, code = None, position = None, num_response_bytes = 0):
         # Build base command byte
@@ -165,4 +170,4 @@ class Krone9000FBM:
     
     def d_update(self):
         # Compatibility function for SplitFlapDisplay class
-        self.set_all()
\ No newline at end of file
+        self.set_all()
