@@ -18,6 +18,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import serial
 import time
 
+from ..utils.base_serial import BaseSerialPort
+
 
 class OmegaRS485Controller:
     """
@@ -27,7 +29,7 @@ class OmegaRS485Controller:
 
     def __init__(self, port, debug = False, exclusive = False):
         self.debug = debug
-        if isinstance(port, serial.Serial):
+        if isinstance(port, serial.Serial) or isinstance(port, BaseSerialPort):
             self.port = port
         else:
             self.port = serial.Serial(port, baudrate=19200, timeout=1.0, exclusive=exclusive)
