@@ -15,4 +15,6 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from .utils import *
\ No newline at end of file
+from .utils import *
+from .tcp_serial import TcpSerialPort
+from .dummy_serial import DummySerialPort
